#
# spec file for package python-fabio
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pyversion 2024.4.0
Name:           python-fabio
Version:        2024.4
Release:        1.2
Summary:        Image IO for images produced by 2D X-ray detectors
License:        BSD-3-Clause AND GPL-2.0-or-later AND LGPL-3.0-or-later AND MIT
URL:            https://github.com/silx-kit/fabio
Source:         https://github.com/silx-kit/fabio/archive/v%{version}.tar.gz#/fabio-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module h5py}
BuildRequires:  %{python_module hdf5plugin}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module meson-python >= 0.11}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyproject-metadata}
BuildRequires:  %{python_module tomli}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  python-rpm-macros
Requires:       python-Pillow
Requires:       python-h5py
Requires:       python-hdf5plugin
Requires:       python-lxml
Requires:       python-numpy
Requires(post): update-alternatives
Requires(postun): update-alternatives
# This package does not support 32 bit arch.
ExcludeArch:    %{ix86} %{arm}
%python_subpackages

%description
FabIO is an I/O library for images produced by 2D X-ray detectors.

%prep
%autosetup -n fabio-%{version}
find src -name '*.py' -and ! -path src/fabio/_version.py -exec sed -i '1{/^#!/d}' '{}' ';' -exec chmod -x '{}' ';'

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand sed -i '1{s|^#!.*$|#!%{__$python}|}' %{buildroot}%{$python_sitearch}/fabio/version.py
%python_clone -a %{buildroot}%{_bindir}/densify_Bragg
%python_clone -a %{buildroot}%{_bindir}/fabio-convert
%python_clone -a %{buildroot}%{_bindir}/fabio_viewer
%python_clone -a %{buildroot}%{_bindir}/eiger2cbf
%python_clone -a %{buildroot}%{_bindir}/eiger2crysalis
%python_expand %fdupes %{buildroot}%{$python_sitearch}

# the master/slave names have changed, we need to uninstall the old set before installing any new flavor
%pre
%python_uninstall_alternative densify-Bragg

%post
%python_install_alternative fabio-convert fabio_viewer eiger2cbf eiger2crysalis densify_Bragg

%postun
%python_uninstall_alternative fabio-convert

%check
export PYTHONDONTWRITEBYTECODE=1
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
$python ./run_tests.py --installed -v
}

%files %{python_files}
%doc README.rst
%license copyright
%python_alternative %{_bindir}/densify_Bragg
%python_alternative %{_bindir}/fabio-convert
%python_alternative %{_bindir}/fabio_viewer
%python_alternative %{_bindir}/eiger2cbf
%python_alternative %{_bindir}/eiger2crysalis
%{python_sitearch}/fabio
%{python_sitearch}/fabio-%{pyversion}.dist-info

%changelog
* Thu Jul  4 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2024.4:
  * Support for new style GE-files (contribution from Patrick Avery)
  * Support sparse frames without background (for XPCS)
  * Support for Numpy v2.0
  * Support Python 3.7-3.12
* Fri Mar  1 2024 Ben Greiner <code@bnavigator.de>
- Update to 2023.10
  * New tutorial on the ccreation of multiframe Tiff
  * Fix regression related to the depreciation of fopen on MSVC compilers (validation code)
  * Clean-up packaging
  * Support Python 3.7-3.12
- FabIO-2023.6.0:
  * Move source code to src
  * Remove anything related to setup.py (i.e. exit setuptools and numpy.distutils)
  * Debian build works only on debian12 (impossible to meet requirements on former versions)
  * Supports python 3.7 - 3.11
- FabIO-2023.4.1:
  * Bugfix (#528) wrong checksum with small CBF files
- FabIO-2023.04:
  * eiger2crysalis generates full CrysalisPro projects, including mask & scan description
  * Support Python 3.7 to 3.11 with Cython 0.21-3.0
- FabIO-2022.12: (12/12/2022):
  * First version declared stable
  * Change the versioning system to calendar
  * Change build-system from numpy.distutils to meson-python
  * Deprecate the usage of setup.py (will be removed in next release)
  * Fix Tif-reader for wrong photometric interpretation
  * Update HiPiCimage
  * Support BigTIFF
  * Improvement of test-coverage
  * Fix issue in ProgressBar in the viewer
  * Fix memory leak in densify
  * Fix EigerImage behavour
  * Drop Python-3.6 (declared EOL 12-2021)
* Tue Nov 29 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove python-six dependency
- Remove python_module macro definition
- More specific python_sitelib in %%files
* Fri Jun 10 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.14.0:
  * fix infinite loop when iterating over lima/eiger image files (#468)
  * fix typo when saving in pilatus/CBF format (#471)
  * fix noisy test on densification (#440)
  * limit version of setuptools (related to the PEP517 and associated regressions)
  * Change logo in documentation
  * Support for Python versions 3.6 to 3.10, tested on amd64, ppc64le and arm64
  * Linux is officially the main platform, Windows and MacOS are supported in best effort mode.
* Thu Apr 21 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.13.0:
  * Allow files to be larger than 2GB (Thanks Wout)
  * Simplify the eiger2cbf tool
  * Correct densification with missing wavelength
  * Correct issue with EDF headers (#459)
  * Support for Python versions 3.6 to 3.10, tested on amd64, ppc64le and
    arm64
  * Densification of sparse data (densify-Bragg) produced by pyFAI
    (sparsify-Bragg)
  * Writer for EigerImage format
  * Writer for LimaImage format
  * Refactor all CLI tools
  * Disable the mask calculation by default in eiger2crysalis
  * Clean-up some debuging prints in CbfImage
  * Correct MrcImage format (and change in tests)
- Use run_tests rather than setup.py tests to run the testsuite.
* Fri Feb 19 2021 andy great <andythe_great@pm.me>
- Update to version 0.11.0.
  * New support for Esperanto image format
    (includes bitfield compression) read & write
  * New support for HDF5 files generated by LImA (read-only so far)
  * New support for HDF5 files generated by Bragg-sparsify
    (definitevely read-only)
  * Improved support for CBF: Magic bytes, headers, + other bug
    corrections
  * Improved supportfor Tiff: Miss interpretation of colormap tags
  * Improved support for GE files gernerated at APS
  * Improved support for Bruker100 image format (read & write)
  * Stop testing for 32-bit operating systems.
- Removed fix_test_brukerimage.py_assertionerror.patch, which was
  included in upstream.
* Fri Feb 19 2021 andy great <andythe_great@pm.me>
- Skip python36 because python-numpy does not support it.
* Sun Sep  6 2020 andy great <andythe_great@pm.me>
- Initial package release.
